Examples — Geraldo Reports Documentation v0.3.4-final documentation

### Navigation

- index
- next |
- previous |
- Geraldo Reports Documentation v0.3.4-final documentation »

# Examples

The following examples are the same you can find in the ‘tests’ package, from source code.

- A Simple Report
- An Intermediary Report
- A report with all kinds of graphic elements
- Child Bands
- Groupping Bands
- SubReports
- Inheritance
- Composition
- Charts with CairoPlot
- Charts with MatPlotLib
- Without Django
- Inline Detail Band
- Inline SubReports
- Auto expading band height
- Two Reports At Once

### Navigation

- index
- next |
- previous |
- Geraldo Reports Documentation v0.3.4-final documentation »